Utility data processing functions for epoched data in pandas dataframes.

Docs https://kutaslab.github.io/spudtr

Also packaged for `conda` installation: https://anaconda.org/kutaslab/spudtr

We gratefully acknowledge the support of grant NICHD 5R01HD022614 for the development of these routines.

